@@ -158,7 +158,7 @@ class BaseTask():
                                 SAVE_SCREENSHOT_SUCCESS_FOLDER, 'success')
 
     def begin_task(self):
-        # Always use undetected in docker
+            # Always use undetected in docker
         if IS_DOCKER:
             self.DRIVER_TYPE = UNDETECTED_DRIVER
         if BaseTask.SKIP_IP_CHECK:
@@ -270,7 +270,8 @@ class BaseTask():
 
     def has_user_id(self):
         return  BaseTask.user.get("user_id") != NULL and BaseTask.user.get("user_id") is not None
-    
+    FORCE_VERSION = None
+
     def create_driver(self, is_eager):
 
         def do_create_driver():
@@ -282,7 +283,8 @@ class BaseTask():
                     BaseTask.user.get("user_id") if self.has_user_id() else None,
                     BaseTask.user.get("window_size", RANDOM),
                     BaseTask.user.get("user_agent", RANDOM),
-                    is_eager)
+                    is_eager,
+                    self.FORCE_VERSION)
 
             driver = retry_if_is_error(
                 run, NETWORK_ERRORS + [(WebDriverException, lambda: delete_corrupted_files(BaseTask.user["user_id"]) if self.has_user_id() else None )], RETRY_ATTEMPTS_HIGH)
